| Title: | Scraper for Chess-Results.com |
|---|---|
| Description: | Scrape data from <https://chess-results.com> and get a clean 'tibble'. Currently supports tournament information, starting rank, playing schedule, pairings/results for rounds, and closing rank. All requests to the <https://chess-results.com> server are made using 'polite'. |
| Authors: | Sirf Haru [aut, cre, cph] |
| Maintainer: | Sirf Haru <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 2026.07.12 |
| Built: | 2026-07-11 19:55:38 UTC |
| Source: | https://github.com/cran/chessResults |
Scrape a list of tibble from chess-results.com by giving a URL or tournament ID. (The tournament ID can be found in the URL). It currently returns tournament information, starting rank, playing schedule, pairings/results for each round, and closing rank.
chess_results(id, user_agent = "chessResults R package")chess_results(id, user_agent = "chessResults R package")
id |
The URL or the tournament ID of the tournament page |
user_agent |
The User Agent to be used when accessing chess-results.com |
A list of tibble about the different aspects of the tournament. The sub-list contains the data for the pairings/results for each round.
chess_results("https://s3.chess-results.com/tnr1445162.aspx?lan=1")chess_results("https://s3.chess-results.com/tnr1445162.aspx?lan=1")