The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {chessResults}


Title: Scraper for Chess-Results.com
Version: 2026.07.12
Description: Scrape data from https://chess-results.com and get a clean 'tibble'. Currently supports tournament information, starting rank, playing schedule, pairings/results for rounds, and closing rank. All requests to the https://chess-results.com server are made using 'polite'.
License: GPL (≥ 3)
URL: https://codeberg.org/SirfHaru/chessresults https://sirfharu.codeberg.page/chessresults
BugReports: https://codeberg.org/SirfHaru/chessresults/issues
Imports: dplyr (≥ 1.2.1), janitor (≥ 2.2.1), polite (≥ 0.1.4), stringr (≥ 1.6.0), tibble (≥ 3.3.1), tidyr (≥ 1.3.2), readr (≥ 2.2.0), rvest (≥ 1.0.5)
Depends: R (≥ 4.6.0)
Suggests: spelling (≥ 2.3.2)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 8.0.0
Language: en-US
NeedsCompilation: no
Packaged: 2026-07-11 15:15:32 UTC; insaan
Author: Sirf Haru [aut, cre, cph]
Maintainer: Sirf Haru <sirfharu@proton.me>
Repository: CRAN
Date/Publication: 2026-07-11 16:20:02 UTC

Get all data for a tournament

Description

Scrape a list of tibble from chess-results.com by giving a URL or tournament ID. (The tournament ID can be found in the URL). It currently returns tournament information, starting rank, playing schedule, pairings/results for each round, and closing rank.

Usage

chess_results(id, user_agent = "chessResults R package")

Arguments

id

The URL or the tournament ID of the tournament page

user_agent

The User Agent to be used when accessing chess-results.com

Value

A list of tibble about the different aspects of the tournament. The sub-list contains the data for the pairings/results for each round.

Examples


chess_results("https://s3.chess-results.com/tnr1445162.aspx?lan=1")

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.